@@ -1,7 +1,6 @@
-﻿# -*- coding: utf-8 -*- 
-
+﻿# -*- coding: utf-8 -*-
 from enum import IntEnum
-from iqsopenapi.enums.Enums import *
+from iqsopenapi.models.Contract import *
 
 class AssetInfo(object):
     """资产信息"""
@@ -9,7 +8,7 @@ class AssetInfo(object):
     def __init__(self):
 
         """券商账户编号"""
-        self.StrategyID = ""
+        self.StrategyID = 0
 
         """总资产"""
         self.TotalAsset = 0.0
@@ -24,9 +23,9 @@ class AssetInfo(object):
         self.Margin = 0.0
 
         """初始资产"""
-        self.InitAsset=0.0
+        self.InitAsset = 0.0
 
-        self.Withdraw=0.0
+        self.Withdraw = 0.0
 
         """币种"""
         self.Currency = Currency.CNY
