@@ -1,11 +1,9 @@
 # -*- coding: utf-8 -*-
 
-from iqsopenapi.models.Models import *
 from iqsopenapi.models.AssetInfo import *
 from iqsopenapi.models.BarData import *
 from iqsopenapi.models.Contract import *
-from iqsopenapi.models.KlineData import *
 from iqsopenapi.models.Order import *
 from iqsopenapi.models.Position import *
 from iqsopenapi.models.TickData import *
-from iqsopenapi.models.ResultInfo import *
\ No newline at end of file
+from iqsopenapi.models.ResultInfo import *
