@@ -2,7 +2,7 @@
 class ITradeApi(object):
     """交易接口"""
 
-    def __init__(self,connectionUrl,apiHost,strategyID,orderChangedCallback,orderExecutionCallback):
+    def __init__(self,connectionUrl,apiHost,strategyID,orderChangedCallback,orderExecutionCallback,orderCancelledCallBack):
         """构造函数"""
         pass
 
