@@ -1,6 +1,6 @@
 # -*- coding: utf-8 -*-
-from iqsopenapi.util.HttpHelper import *
-from iqsopenapi.util.LogRecord import *
+from iqsopenapi.util.HttpUtil import *
+from iqsopenapi.util.logutil import *
 from iqsopenapi.util.MemCache import *
 from iqsopenapi.util.DES3Cryptogram import *
 from iqsopenapi.util.ParseManager import *
@@ -16,7 +16,7 @@ import string
 import json
 import time
 import uuid
-import iqsopenapi.util.LogRecord
+import iqsopenapi.util.logutil
 import datetime
 from concurrent.futures.thread import ThreadPoolExecutor
 
@@ -288,11 +288,11 @@ class RealTradeApi(ITradeApi):
 
     def __wirteError(self, error):
         '''写错误日志'''
-        LogRecord.writeLog('FutRealTradeApiError', 'E- ;' + error)
+        logutil.writeLog('FutRealTradeApiError', 'E- ;' + error)
 
     def __wirteInfo(self, info):
         '''写日志'''
-        LogRecord.writeLog('FutRealTradeApi', 'I- ;' + info)
+        logutil.writeLog('FutRealTradeApi', 'I- ;' + info)
 
 def __object_2_json(x):
     return x.__dict__
@@ -301,7 +301,7 @@ if __name__ == '__main__':
     """测试"""
     try:
         raise Exception('未测试')
-        LogRecord.setLogPath("d:/logs/")
+        logutil.setLogPath("d:/logs/")
         trade = FutRealTradeApi('2-xk1211231243242314123534523453',None)
 
         position = trade.GetPositions()
